@@ -22,10 +22,10 @@ import (
 	"fmt"
 	"os"
 
-	"git.zabbix.com/ap/mssql/plugin"
-	"git.zabbix.com/ap/plugin-support/plugin/flag"
-	"git.zabbix.com/ap/plugin-support/zbxerr"
 	_ "github.com/microsoft/go-mssqldb"
+	"golang.zabbix.com/plugin/mssql/plugin"
+	"golang.zabbix.com/sdk/plugin/flag"
+	"golang.zabbix.com/sdk/zbxerr"
 )
 
 const copyrightMessage = //
@@ -47,7 +47,7 @@ var (
 	PLUGIN_VERSION_RC    = ""
 	PLUGIN_VERSION_MAJOR = 6
 	PLUGIN_VERSION_MINOR = 0
-	PLUGIN_VERSION_PATCH = 29
+	PLUGIN_VERSION_PATCH = 30
 	PLUGIN_LICENSE_YEAR  = 2023
 )
 
